# BiQwen

This module allows you to train a [Qwen model](https://huggingface.co/Qwen) with bidirectional attention.

## Installation

```bash
pip install biqwen
```

## Usage

See [examples/biqwen3_ner.py](./examples/biqwen3_ner.py) for usage examples.